@@ -2,10 +2,28 @@ import logging
 from contextlib import contextmanager
 from typing import Union, List
 from logging import DEBUG, INFO, WARNING, CRITICAL
+from opentelemetry import trace
+from functools import wraps
+import inspect
 
 
 __all__ = ["configure_logger", "get_logger", "Loggable", "classproperty"]
 
+def create_span_decorator():
+
+    def span_decorator(f):
+        @wraps(f)
+        def new_f(*args, **kwargs):
+            module_name = __name__
+            module = inspect.getmodule(f)
+            if module is not None:
+                module_name = module.__name__
+            with trace.get_tracer(module_name).start_as_current_span(f.__qualname__, kind=trace.SpanKind.CLIENT):
+                return f(*args, **kwargs)
+
+        return new_f
+
+    return span_decorator
 
 class classproperty(property):
     """Helper class for defining a class method as a property"""
