@@ -3,6 +3,7 @@ from typing import Iterable, Tuple, Optional
 from ubai_client.apis import SearchApi
 from ubai_client.models import ArtifactStorage
 from ubai_client.exceptions import OpenApiException
+from time import sleep
 
 
 @click.command()
@@ -46,9 +47,10 @@ def cli(
         try:
             search_results = search_api.find_all_artifacts(search_opts)
             return [result.id for result in search_results]
-        except OpenApiException:
+        except Exception:
             if (try_index + 1) >= total_attempts:
                 raise
+            sleep(10)
 
 
 if __name__ == "__main__":
