@@ -6,6 +6,7 @@ from utf_queue_client.clients.ubai_artifact_upload_request_producer import (
 from urllib import parse
 import click
 from typing import Iterable, Tuple
+from time import sleep
 
 
 @click.command()
@@ -72,3 +73,4 @@ def cli(
         except Exception:
             if (try_index + 1) >= total_attempts:
                 raise
+            sleep(10)
